@@ -149,6 +149,11 @@ GAK <- function(x, y, ..., sigma = NULL, window.size = NULL, normalize = TRUE,
     logGAK
 }
 
+#' @rdname GAK
+#' @export
+#'
+gak <- GAK
+
 # ==================================================================================================
 # Wrapper for proxy::dist
 # ==================================================================================================
