@@ -197,7 +197,7 @@ all_cent <- function(case = NULL, distmat = NULL, distfun, control, fuzzy = FALS
                                    dots = list(...)))
 
             ## coerce back to list
-            any2list(cent)
+            tslist(cent)
         }
     } else {
         allcent <- function(x, cl_id, k, cent, cl_old, ...) {
